interface HookConfig {
    shallow: boolean;
}
type Selector<State, T> = (state: State) => T;
type Hook<State> = <T>(selector: Selector<State, T>, config?: HookConfig) => T;
type SetStateCallback<State> = (state: State) => Partial<State> | Promise<Partial<State>>;
type SetState<State> = (obj: Partial<State> | SetStateCallback<State>, replace?: boolean) => Promise<void>;
type ListenerFn<T> = (state: T) => void;
type UnSubscribeFn = () => boolean;
type SubscribeFn<T> = (lFn: ListenerFn<T>) => UnSubscribeFn;
type API<T> = {
    /** Returns the current state */
    get: () => T;
    /** Merge or replace values in the state */
    set: SetState<T>;
    /** Subscribes to the state, called on every state change */
    subscribe: SubscribeFn<T>;
    /** It removes all listeners */
    destroy: () => void;
};

/**
 * It creates a store with initial values.
 */
declare function create<State>(initialState: State): [Hook<State>, SetState<State>, API<State>];

export { API, Hook, HookConfig, ListenerFn, Selector, SetState, SetStateCallback, SubscribeFn, UnSubscribeFn, create };
